import { baseRequest, request } from '../request';
/** Login */
export function fetchLogin(data: object) {
  return request<Api.Auth.LoginToken>({
    url: '/api/v1/login',
    method: 'post',
    data
  });
}

/** Get user info */
export function fetchGetUserInfo() {
  return request<Api.Auth.UserInfo>({ url: '/api/v1/getinfo' });
}

/** Get Code demo */
export function fetchGetCode() {
  return baseRequest<Api.Auth.CodeImg>({ url: '/api/v1/captcha' });
}

/** Get Login Pubkey */
export function fetchLoginPubkey() {
  return baseRequest<Api.Auth.Pubkey>({ url: '/api/v1/login/pubkey' });
}

/**
 * Refresh token
 *
 * @param refreshToken Refresh token
 */
export function fetchRefreshToken(refreshToken: string) {
  return request<Api.Auth.LoginToken>({
    url: '/auth/refreshToken',
    method: 'post',
    data: {
      refreshToken
    }
  });
}

/**
 * return custom backend error
 *
 * @param code error code
 * @param msg error message
 */
export function fetchCustomBackendError(code: string, msg: string) {
  return request({ url: '/auth/error', params: { code, msg } });
}
