import type { ElegantConstRoute, LastLevelRouteKey } from '@elegant-router/types';

interface DataItem {
  name: string;
  path: string;
  component: string;
  title: string;
  icon: string;
  sort: number;
  children?: DataItem[];
  visible: string;
}

function pathToArray(path: string) {
  return path.split('/').filter(e => e);
}

function getLastPath(path: string) {
  const result = pathToArray(path);
  if (result.length) {
    return `/${result.pop()}`;
  }
  return '';
}

function getTransComponentName(path: string) {
  return pathToArray(path).join('_');
}

function getTransComponent(path: string, level: number, item: DataItem) {
  const { children } = item;
  let isChildren = true;
  if (!children || children?.length === 0) {
    isChildren = false;
  }
  const name = getTransComponentName(path);
  if (level === 0) {
    if (!isChildren) {
      return `layout.base$view.${name}`;
    }
    return `layout.base`;
  }
  if (level === 1) {
    if (!isChildren) {
      return `view.${name}`;
    }
    return '';
  }
  return `view.${name}`;
}

function transData(menus: DataItem[], level: number = 0, basePath: string = ''): ElegantConstRoute[] {
  return menus.map(item => {
    const itemPath = getLastPath(item.path);
    const fullPath = basePath ? `${basePath}${itemPath}` : itemPath;
    const obj: ElegantConstRoute = {
      name: getTransComponentName(fullPath),
      path: fullPath,
      component: getTransComponent(fullPath, level, item),
      meta: {
        title: item.title,
        order: item.sort,
        localIcon: item.icon,
        _level: level,
        hideInMenu: item.visible === '1'
      },
      children: []
    };
    if (Array.isArray(item.children)) {
      obj.children = transData(item.children, level + 1, fullPath);
    }
    return obj;
  });
}

export function transformToTargetData(data: DataItem[]): {
  routes: ElegantConstRoute[];
  home: LastLevelRouteKey;
} {
  return {
    routes: transData(data),
    home: 'admin_sys-user'
  };
}
